pub struct CorrelationId(pub String);Expand description
A correlation ID returned from async commands.
This can be used to track the result of an async operation via Kafka or other message brokers.
Tuple Fields
0: StringTrait Implementations
Sourceimpl Clone for CorrelationId
impl Clone for CorrelationId
Sourcefn clone(&self) -> CorrelationId
fn clone(&self) -> CorrelationId
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CorrelationId
impl Debug for CorrelationId
Sourceimpl Display for CorrelationId
impl Display for CorrelationId
Sourceimpl From<String> for CorrelationId
impl From<String> for CorrelationId
Sourceimpl Hash for CorrelationId
impl Hash for CorrelationId
Sourceimpl PartialEq for CorrelationId
impl PartialEq for CorrelationId
impl Eq for CorrelationId
impl StructuralPartialEq for CorrelationId