StateView

Struct StateView 

pub struct StateView {
    pub database: DatabaseName,
    pub name: StateViewName,
    pub version: u64,
    pub event_selector: EventSelector,
    pub last_modified_revision: Option<u64>,
    pub last_modified_timestamp: Option<DateTime<Utc>>,
    pub content_type: String,
    pub content_schema_url: Option<String>,
    pub content: Option<Vec<u8>>,
}
A materialized state view.

Fields

database: DatabaseName

The database this state view belongs to.

name: StateViewName

The name of this state view.

version: u64

The version of this state view definition.

event_selector: EventSelector

The event selector that determines which events affect this view.

last_modified_revision: Option<u64>

The revision at which this view was last modified, if any.

last_modified_timestamp: Option<DateTime<Utc>>

The timestamp when this view was last modified, if any.

content_type: String

The content type of the serialized state (e.g., “application/json”).

content_schema_url: Option<String>

Optional URL to the schema for the content.

content: Option<Vec<u8>>

The serialized state content, if any.

Implementations

Source

impl StateView

pub fn has_content(&self) -> bool

Check if this state view has content.

pub fn content_bytes(&self) -> Option<&[u8]>

Get the content as bytes, if present.