TransactionBuilder

Struct TransactionBuilder 

pub struct TransactionBuilder { /* private fields */ }
Builder for constructing transactions.

Example

let db = conn
    .transaction()
    .event(event1)
    .event(event2)
    .condition(AppendCondition::must_not_exist(selector))
    .with_correlation_id("order-12345")
    .commit()
    .await?;

Implementations

Source

impl TransactionBuilder

pub fn new(connection: Connection) -> Self

Create a new transaction builder.

pub fn event(self, event: ProspectiveEvent) -> Self

Add an event to the transaction.

pub fn events(self, events: impl IntoIterator<Item = ProspectiveEvent>) -> Self

Add multiple events to the transaction.

pub fn condition(self, condition: AppendCondition) -> Self

Add a condition to the transaction.

pub fn conditions( self, conditions: impl IntoIterator<Item = AppendCondition>, ) -> Self

Add multiple conditions to the transaction.

pub fn require_not_exists(self, selector: EventSelector) -> Self

Require that no events matching the selector exist.

pub fn require_exists(self, selector: EventSelector) -> Self

Require that at least one event matching the selector exists.

pub fn with_transaction_id(self, transaction_id: impl Into<String>) -> Self

Set a specific transaction ID for idempotency.

pub fn with_correlation_id(self, correlation_id: impl Into<String>) -> Self

Set the correlation ID for grouping related events in a business flow.

See: https://github.com/cloudevents/spec/blob/main/cloudevents/extensions/correlation.md

pub fn with_causation_id(self, causation_id: impl Into<String>) -> Self

Set the causation ID for parent-child event relationships.

See: https://github.com/cloudevents/spec/blob/main/cloudevents/extensions/correlation.md

pub async fn commit(self) -> Result<DatabaseAtRevisionImpl, DatabaseError>

Commit the transaction synchronously.

Returns the database at the new revision.

pub async fn commit_async(self) -> Result<CorrelationId, DatabaseError>

Commit the transaction asynchronously.

Returns a correlation ID for tracking.