pub struct DatabaseQuery {
pub selector: Option<EventSelector>,
pub range: Option<QueryRange>,
pub direction: i32,
pub limit: Option<u32>,
}Expand description
Complete database query with selector, range, direction and limits
Fields
selector: Option<EventSelector>range: Option<QueryRange>direction: i32limit: Option<u32>Implementations
Sourceimpl DatabaseQuery
impl DatabaseQuery
Sourcepub fn direction(&self) -> QueryDirection
pub fn direction(&self) -> QueryDirection
Returns the enum value of direction, or the default if the field is set to an invalid enum value.
Sourcepub fn set_direction(&mut self, value: QueryDirection)
pub fn set_direction(&mut self, value: QueryDirection)
Sets direction to the provided enum value.