pub struct ListStateViewDefinitionsRequest {
pub database_name: String,
pub status: Option<i32>,
}Expand description
Read Model Queries
Fields
database_name: Stringstatus: Option<i32>Optionally filter by status
Implementations
Sourceimpl ListStateViewDefinitionsRequest
impl ListStateViewDefinitionsRequest
Sourcepub fn status(&self) -> StateViewStatus
pub fn status(&self) -> StateViewStatus
Returns the enum value of status, or the default if the field is unset or set to an invalid enum value.
Sourcepub fn set_status(&mut self, value: StateViewStatus)
pub fn set_status(&mut self, value: StateViewStatus)
Sets status to the provided enum value.