pub enum DatabaseError {
NotFound(String),
AlreadyExists(String),
ConcurrentWriteCollision,
Timeout,
ServerError(String),
WithContext {
context: OperationContext,
source: Box<DatabaseError>,
},
Identifier(IdentifierError),
Transaction(TransactionError),
}Expand description
Errors related to database operations
Variants
NotFound(String)
AlreadyExists(String)
ConcurrentWriteCollision
Timeout
ServerError(String)
WithContext
Identifier(IdentifierError)
Transaction(TransactionError)
Implementations
Sourceimpl DatabaseError
impl DatabaseError
Sourcepub fn with_context(self, context: OperationContext) -> DatabaseError
pub fn with_context(self, context: OperationContext) -> DatabaseError
Add context to this error.
This wraps the error with additional context about the operation that was being performed when the error occurred.
Example
use evidentsource_core::domain::{DatabaseError, OperationContext};
let err = DatabaseError::NotFound("my-db".to_string());
let with_ctx = err.with_context(OperationContext::new("transact", "my-db"));
assert!(with_ctx.to_string().contains("transact"));Sourcepub fn inner(&self) -> &DatabaseError
pub fn inner(&self) -> &DatabaseError
Get the inner error, stripping any context wrappers.