pub struct Connection { /* private fields */ }Expand description
A connection to an EvidentSource database with live metadata updates.
The connection maintains a background subscription to receive database updates whenever transactions are committed. This enables efficient access to the latest database state without polling.
Example
ⓘ
let es = EvidentSource::connect_to_server("http://localhost:50051").await?;
let conn = es.connect(&DatabaseName::new("my-db")?).await?;
// Get latest database state
let db = conn.latest_database().await?;
println!("Revision: {}", db.revision());Implementations
Sourceimpl Connection
impl Connection
Sourcepub async fn new(
client: EvidentSourceClient,
database_name: DatabaseName,
) -> Result<Self, DatabaseError>
pub async fn new( client: EvidentSourceClient, database_name: DatabaseName, ) -> Result<Self, DatabaseError>
Create a new connection to a database.
This fetches the initial database state and starts a background subscription to receive updates.
Sourcepub async fn close(self) -> Result<(), DatabaseError>
pub async fn close(self) -> Result<(), DatabaseError>
Explicitly close the connection and wait for cleanup.
Sourceimpl Connection
impl Connection
Sourcepub fn list_state_changes(
&self,
) -> impl Stream<Item = StateChangeDefinitionSummary>
pub fn list_state_changes( &self, ) -> impl Stream<Item = StateChangeDefinitionSummary>
Sourcepub async fn fetch_transaction_by_id(
&self,
transaction_id: &str,
) -> Result<Transaction, DatabaseError>
pub async fn fetch_transaction_by_id( &self, transaction_id: &str, ) -> Result<Transaction, DatabaseError>
Sourcepub fn client(&self) -> &EvidentSourceClient
pub fn client(&self) -> &EvidentSourceClient
Get a reference to the underlying gRPC client.
This provides access to low-level operations not exposed through the high-level API.
Sourcepub fn transaction(&self) -> TransactionBuilder
pub fn transaction(&self) -> TransactionBuilder
Sourcepub fn state_change(
&self,
name: &str,
version: StateChangeVersion,
) -> StateChangeBuilder
pub fn state_change( &self, name: &str, version: StateChangeVersion, ) -> StateChangeBuilder